==> percona-xtradb-cluster_8.0.34-26.orig.tar.gz: Percona-XtraDB-Cluster-8.0.34-26/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "C"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_C
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_abort.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_abort.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_backtrace.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_backtrace.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_crc32c.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_crc32c.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_dbug.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_dbug.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_fifo.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_fifo.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_hexdump.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_hexdump.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_init.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_init.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_limits.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_limits.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_lock_step.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_lock_step.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_mem.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_mem.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_mmh3.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_mmh3.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_rand.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_rand.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_spooky.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_spooky.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_threads.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_threads.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_time.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_time.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_to.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_to.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_utils.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_utils.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_uuid.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_uuid.c.o"
  )
set(CMAKE_C_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_C
  "BOOST_DATE_TIME_POSIX_TIME_STD_CONFIG=1"
  "BOOST_NO_CXX98_FUNCTION_BASE"
  "GALERA_HAVE_SSL"
  "HAVE_ASIO_HPP"
  "HAVE_BOOST_SHARED_PTR_HPP"
  "HAVE_BYTESWAP_H"
  "HAVE_COMMON_H"
  "HAVE_CONFIG_H"
  "HAVE_ENDIAN_H"
  "HAVE_PSI_INTERFACE=1"
  "HAVE_STD_ARRAY"
  "HAVE_STD_UNORDERED_MAP"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "NDEBUG"
  "OPENSSL_HAS_SET_ECDH_AUTO"
  "PXC"
  "WSREP_PS_VAR_VALUE_BUFF_SIZE=4096"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_USE_MATH_DEFINES"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  )

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "wsrep-lib/include"
  "wsrep-lib/wsrep-API/v26"
  "."
  "include"
  "percona-xtradb-cluster-galera"
  "percona-xtradb-cluster-galera/common"
  "percona-xtradb-cluster-galera/galera/src"
  "percona-xtradb-cluster-galera/galerautils/src"
  "percona-xtradb-cluster-galera/gcache/src"
  "percona-xtradb-cluster-galera/gcomm/src"
  "percona-xtradb-cluster-galera/gcs/src"
  "percona-xtradb-cluster-galera/wsrep/src"
  "extra/protobuf/protobuf-3.19.4/src"
  "percona-xtradb-cluster-galera/asio"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils_log.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils_hw_crc32c.dir/DependInfo.cmake"
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")

==> percona-xtradb-cluster_8.0.39-30.orig.tar.gz: Percona-XtraDB-Cluster-8.0.39-30/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "C"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_C
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_abort.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_abort.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_backtrace.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_backtrace.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_crc32c.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_crc32c.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_dbug.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_dbug.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_fifo.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_fifo.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_hexdump.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_hexdump.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_init.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_init.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_limits.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_limits.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_lock_step.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_lock_step.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_mem.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_mem.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_mmh3.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_mmh3.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_rand.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_rand.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_spooky.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_spooky.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_threads.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_threads.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_time.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_time.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_to.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_to.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_utils.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_utils.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/gu_uuid.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/gu_uuid.c.o"
  )
set(CMAKE_C_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_C
  "BOOST_BIND_GLOBAL_PLACEHOLDERS=1"
  "BOOST_DATE_TIME_POSIX_TIME_STD_CONFIG=1"
  "BOOST_NO_CXX98_FUNCTION_BASE"
  "GALERA_HAVE_SSL"
  "HAVE_ASIO_HPP"
  "HAVE_BOOST_SHARED_PTR_HPP"
  "HAVE_BYTESWAP_H"
  "HAVE_COMMON_H"
  "HAVE_CONFIG_H"
  "HAVE_ENDIAN_H"
  "HAVE_PSI_INTERFACE=1"
  "HAVE_STD_ARRAY"
  "HAVE_STD_UNORDERED_MAP"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "NDEBUG"
  "OPENSSL_HAS_SET_ECDH_AUTO"
  "PXC"
  "WSREP_PS_VAR_VALUE_BUFF_SIZE=4096"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_USE_MATH_DEFINES"
  "_XOPEN_SOURCE=600"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  )

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "wsrep-lib/include"
  "wsrep-lib/wsrep-API/v26"
  "."
  "include"
  "percona-xtradb-cluster-galera"
  "percona-xtradb-cluster-galera/common"
  "percona-xtradb-cluster-galera/galera/src"
  "percona-xtradb-cluster-galera/galerautils/src"
  "percona-xtradb-cluster-galera/gcache/src"
  "percona-xtradb-cluster-galera/gcomm/src"
  "percona-xtradb-cluster-galera/gcs/src"
  "percona-xtradb-cluster-galera/wsrep/src"
  "extra/protobuf/protobuf-24.4/src"
  "percona-xtradb-cluster-galera/asio"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils_log.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils_hw_crc32c.dir/DependInfo.cmake"
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")
